==> downloads.php?file=source%2FTrueCrypt+6.1a+Source.tar.gz: truecrypt-6.1a-source/Mount/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Mount.rc
//
#define IDR_MOUNT_TLB                   1
#define IDD_MOUNT_DLG                   101
#define IDD_PASSWORDCHANGE_DLG          102
#define IDB_DRIVEICON                   103
#define IDD_PASSWORD_DLG                104
#define IDB_DRIVEICON_MASK              105
#define IDR_MENU                        106
#define IDD_PREFERENCES_DLG             107
#define IDD_VOLUME_PROPERTIES           108
#define IDR_MOUNT_RSRC_HEADER           109
#define IDS_UACSTRING                   110
#define IDB_LOGO_288DPI                 111
#define IDB_LOGO_96DPI                  112
#define IDB_SYS_DRIVEICON               113
#define IDB_SYS_DRIVEICON_MASK          114
#define IDD_TOKEN_PREFERENCES           115
#define IDD_SYSENC_SETTINGS             116
#define IDC_PREF_MOUNT_READONLY         1000
#define IDC_PREF_MOUNT_REMOVABLE        1001
#define IDC_VERIFY                      1002
#define IDC_PREF_BKG_TASK_ENABLE        1003
#define IDC_OLD_PASSWORD                1004
#define IDC_CACHE                       1005
#define IDC_NO_HISTORY                  1006
#define IDC_DRIVELIST                   1007
#define IDC_PREF_OPEN_EXPLORER          1008
#define IDC_ENABLE_KEYFILES             1009
#define IDC_VOLUME_PROPERTIES_LIST      1010
#define IDC_PREF_CLOSE_DISMOUNTED_WINDOWS 1011
#define IDC_ENABLE_NEW_KEYFILES         1012
#define IDC_PRESERVE_TIMESTAMPS         1013
#define IDC_PREF_WIPE_CACHE_ON_EXIT     1014
#define IDC_PKCS5_PRF_ID                1015
#define IDC_PREF_CACHE_PASSWORDS        1016
#define IDC_DIRECTORY                   1017
#define IDC_PREF_DISMOUNT_LOGOFF        1018
#define IDC_BROWSE_DIRS                 1019
#define IDC_PREF_DISMOUNT_INACTIVE      1020
#define IDC_AUTORUN_DISABLE             1021
#define IDC_AUTORUN_START               1022
#define IDC_AUTORUN_MOUNT               1023
#define IDC_VOLUME_NAME                 1024
#define IDC_COPY_WIZARD                 1025
#define IDC_MOUNT_OPTIONS               1026
#define IDT_TRAVELER_MOUNT              1027
#define IDT_MOUNT_LETTER                1028
#define IDT_MOUNT_SETTINGS              1029
#define IDC_KEY_FILES                   1030
#define IDC_NEW_KEYFILES                1031
#define IDC_KEYFILES                    1032
#define IDC_VOLUME                      1033
#define IDC_PASSWORD                    1034
#define IDC_BROWSE_FILES                1035
#define IDC_SELECT_DEVICE               1036
#define IDC_CREATE_VOLUME               1037
#define IDC_VOLUME_TOOLS                1038
#define IDC_WIPE_CACHE                  1039
#define IDC_MOUNTALL                    1040
#define IDD_TRAVELER_DLG                1041
#define IDC_SELECT_FILE                 1042
#define IDD_HOTKEYS_DLG                 1043
#define IDC_VOLUME_PROPERTIES           1044
#define IDT_FILE_SETTINGS               1045
#define IDT_AUTORUN                     1046
#define IDT_TRAVEL_INSERTION            1047
#define IDT_TRAVEL_ROOT                 1048
#define IDT_VOLUME                      1049
#define IDT_PASSWORD                    1050
#define IDT_CURRENT                     1051
#define IDT_NEW                         1052
#define IDT_NEW_PASSWORD                1053
#define IDT_CONFIRM_PASSWORD            1054
#define IDT_PKCS5_PRF                   1055
#define IDT_PW_CACHE_OPTIONS            1056
#define IDT_DEFAULT_MOUNT_OPTIONS       1057
#define IDT_WINDOWS_RELATED_SETTING     1058
#define IDC_CREATE                      1059
#define IDC_EXIT                        1060
#define IDC_TRAVEL_OPEN_EXPLORER        1061
#define IDC_TRAV_CACHE_PASSWORDS        1062
#define IDC_UNMOUNTALL                  1063
#define IDT_TASKBAR_ICON                1064
#define IDT_AUTO_DISMOUNT               1065
#define IDC_PREF_FORCE_AUTO_DISMOUNT    1066
#define IDC_PREF_DISMOUNT_INACTIVE_TIME 1067
#define IDT_MINUTES                     1068
#define IDC_PREF_DISMOUNT_SCREENSAVER   1069
#define IDC_PREF_DISMOUNT_POWERSAVING   1070
#define IDT_AUTO_DISMOUNT_ON            1071
#define IDC_PREF_WIPE_CACHE_ON_AUTODISMOUNT 1072
#define IDC_CLOSE_BKG_TASK_WHEN_NOVOL   1073
#define IDT_LOGON                       1074
#define IDC_PREF_LOGON_START            1075
#define IDC_PREF_LOGON_MOUNT_DEVICES    1076
#define IDC_PREF_LOGON_MOUNT_FAVORITES  1077
#define IDC_SHOW_PASSWORD_CHPWD_NEW     1078
#define IDC_DISMOUNT_CONFIRM_MSG_BOX    1079
#define IDC_SHOW_PASSWORD_CHPWD_ORI     1080
#define IDC_DISMOUNT_CONFIRM_PLAY_SOUND 1081
#define IDC_HOTKEY_ASSIGN               1082
#define IDC_HOTKEY_REMOVE               1083
#define IDC_HOTKEY_KEY                  1084
#define IDT_HOTKEY_KEY                  1085
#define IDC_HOTKEY_LIST                 1086
#define IDC_RESET_HOTKEYS               1087
#define IDT_DISMOUNT_ACTION             1088
#define IDT_ASSIGN_HOTKEY               1089
#define IDC_HK_MOD_SHIFT                1090
#define IDC_HK_MOD_CTRL                 1091
#define IDC_HK_MOD_ALT                  1092
#define IDC_HK_MOD_WIN                  1093
#define IDC_SHOW_PASSWORD               1094
#define IDC_LOGO                        1095
#define IDT_PKCS11_LIB_PATH             1096
#define IDC_PKCS11_MODULE               1097
#define IDC_SELECT_PKCS11_MODULE        1098
#define IDC_AUTO_DETECT_PKCS11_MODULE   1099
#define IDC_CLOSE_TOKEN_SESSION_AFTER_MOUNT 1100
#define IDT_SECURITY_OPTIONS            1101
#define IDC_DISABLE_BOOT_LOADER_OUTPUT  1102
#define IDC_ALLOW_ESC_PBA_BYPASS        1103
#define IDC_CUSTOM_BOOT_LOADER_MESSAGE  1104
#define IDC_BOOT_LOADER_CACHE_PASSWORD  1105
#define IDC_MORE_SETTINGS               1106
#define IDT_CUSTOM_BOOT_LOADER_MESSAGE  1107
#define IDC_CUSTOM_BOOT_LOADER_MESSAGE_HELP 1108
#define IDT_BOOT_LOADER_SCREEN_OPTIONS  1109
#define IDT_PKCS11_LIB_HELP             1110
#define IDM_HELP                        40001
#define IDM_ABOUT                       40002
#define IDM_UNMOUNT_VOLUME              40003
#define IDM_CLEAR_HISTORY               40004
#define IDM_FORUMS                      40005
#define IDM_BENCHMARK                   40006
#define IDM_TRAVELER                    40007
#define IDM_MOUNT_VOLUME_OPTIONS        40008
#define IDM_FAQ                         40009
#define IDM_REFRESH_DRIVE_LETTERS       40010
#define IDM_DEFAULT_KEYFILES            40011
#define IDM_WEBSITE                     40012
#define IDM_MOUNTALL                    40013
#define IDM_UNMOUNTALL                  40014
#define IDM_MOUNT_VOLUME                40015
#define IDM_CHANGE_PASSWORD             40016
#define IDM_VOLUME_WIZARD               40017
#define IDM_CREATE_VOLUME               40018
#define IDM_WIPE_CACHE                  40019
#define IDM_PREFERENCES                 40020
#define IDM_LICENSE                     40021
#define IDM_SELECT_FILE                 40022
#define IDM_SELECT_DEVICE               40023
#define IDM_VOLUME_PROPERTIES           40024
#define IDM_LANGUAGE                    40025
#define IDM_MOUNT_FAVORITE_VOLUMES      40026
#define IDM_SAVE_FAVORITE_VOLUMES       40027
#define IDM_BACKUP_VOL_HEADER           40028
#define IDM_RESTORE_VOL_HEADER          40029
#define IDM_HOTKEY_SETTINGS             40030
#define IDM_TC_DOWNLOADS                40031
#define IDM_NEWS                        40032
#define IDM_BUGREPORT                   40033
#define IDM_CONTACT                     40034
#define IDM_VERSION_HISTORY             40035
#define IDM_HOMEPAGE                    40036
#define IDM_TEST_VECTORS                40037
#define IDM_ADD_REMOVE_VOL_KEYFILES     40038
#define IDM_REMOVE_ALL_KEYFILES_FROM_VOL 40039
#define IDM_GENERATE_KEYFILE            40040
#define IDM_CHANGE_HEADER_KEY_DERIV_ALGO 40041
#define IDM_KEYFILE_GENERATOR           40042
#define IDM_SET_DEFAULT_KEYFILES        40043
#define IDM_ONLINE_TUTORIAL             40044
#define IDM_ONLINE_HELP                 40045
#define IDM_DONATIONS                   40046
#define IDM_CHANGE_SYS_HEADER_KEY_DERIV_ALGO 40047
#define IDM_CHANGE_SYS_PASSWORD         40048
#define IDM_CREATE_RESCUE_DISK          40049
#define IDM_PERMANENTLY_DECRYPT_SYS     40050
#define IDM_VERIFY_RESCUE_DISK          40051
#define IDM_SYSTEM_ENCRYPTION_STATUS    40052
#define IDM_ENCRYPT_SYSTEM_DEVICE       40053
#define IDM_SYSENC_RESUME               40054
#define IDM_MOUNT_SYSENC_PART_WITHOUT_PBA 40055
#define IDM_CREATE_HIDDEN_OS            40056
#define IDM_TOKEN_PREFERENCES           40057
#define IDM_CLOSE_ALL_TOKEN_SESSIONS    40058
#define IDM_SYS_ENC_SETTINGS            40059
#define IDM_SYSENC_SETTINGS             40060
#define IDM_RESUME_INTERRUPTED_PROC     40061
#define IDM_MANAGE_TOKEN_KEYFILES       40062

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        117
#define _APS_NEXT_COMMAND_VALUE         40063
#define _APS_NEXT_CONTROL_VALUE         1111
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> downloads.php?file=source%2FTrueCrypt+6.3a+Source.tar.gz: truecrypt-6.3a-source/Mount/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Mount.rc
//
#define IDR_MOUNT_TLB                   1
#define IDD_MOUNT_DLG                   101
#define IDD_PASSWORDCHANGE_DLG          102
#define IDB_DRIVEICON                   103
#define IDD_PASSWORD_DLG                104
#define IDB_DRIVEICON_MASK              105
#define IDR_MENU                        106
#define IDD_PREFERENCES_DLG             107
#define IDD_VOLUME_PROPERTIES           108
#define IDR_MOUNT_RSRC_HEADER           109
#define IDS_UACSTRING                   110
#define IDB_LOGO_288DPI                 111
#define IDB_LOGO_96DPI                  112
#define IDB_SYS_DRIVEICON               113
#define IDB_SYS_DRIVEICON_MASK          114
#define IDD_TOKEN_PREFERENCES           115
#define IDD_SYSENC_SETTINGS             116
#define IDC_PREF_MOUNT_READONLY         1000
#define IDC_PREF_MOUNT_REMOVABLE        1001
#define IDC_VERIFY                      1002
#define IDC_PREF_BKG_TASK_ENABLE        1003
#define IDC_OLD_PASSWORD                1004
#define IDC_CACHE                       1005
#define IDC_NO_HISTORY                  1006
#define IDC_DRIVELIST                   1007
#define IDC_PREF_OPEN_EXPLORER          1008
#define IDC_ENABLE_KEYFILES             1009
#define IDC_VOLUME_PROPERTIES_LIST      1010
#define IDC_PREF_CLOSE_DISMOUNTED_WINDOWS 1011
#define IDC_ENABLE_NEW_KEYFILES         1012
#define IDC_PRESERVE_TIMESTAMPS         1013
#define IDC_PREF_WIPE_CACHE_ON_EXIT     1014
#define IDC_PKCS5_PRF_ID                1015
#define IDC_PREF_CACHE_PASSWORDS        1016
#define IDC_DIRECTORY                   1017
#define IDC_PREF_DISMOUNT_LOGOFF        1018
#define IDC_BROWSE_DIRS                 1019
#define IDC_PREF_DISMOUNT_INACTIVE      1020
#define IDC_AUTORUN_DISABLE             1021
#define IDC_AUTORUN_START               1022
#define IDC_AUTORUN_MOUNT               1023
#define IDC_VOLUME_NAME                 1024
#define IDC_COPY_WIZARD                 1025
#define IDC_MOUNT_OPTIONS               1026
#define IDT_TRAVELER_MOUNT              1027
#define IDT_MOUNT_LETTER                1028
#define IDT_MOUNT_SETTINGS              1029
#define IDC_KEY_FILES                   1030
#define IDC_NEW_KEYFILES                1031
#define IDC_KEYFILES                    1032
#define IDC_VOLUME                      1033
#define IDC_PASSWORD                    1034
#define IDC_BROWSE_FILES                1035
#define IDC_SELECT_DEVICE               1036
#define IDC_CREATE_VOLUME               1037
#define IDC_VOLUME_TOOLS                1038
#define IDC_WIPE_CACHE                  1039
#define IDC_MOUNTALL                    1040
#define IDD_TRAVELER_DLG                1041
#define IDC_SELECT_FILE                 1042
#define IDD_HOTKEYS_DLG                 1043
#define IDC_VOLUME_PROPERTIES           1044
#define IDD_SYS_FAVORITES_SETTINGS      1045
#define IDT_FILE_SETTINGS               1046
#define IDT_AUTORUN                     1047
#define IDT_TRAVEL_INSERTION            1048
#define IDT_TRAVEL_ROOT                 1049
#define IDT_VOLUME                      1050
#define IDT_PASSWORD                    1051
#define IDT_CURRENT                     1052
#define IDT_NEW                         1053
#define IDT_NEW_PASSWORD                1054
#define IDT_CONFIRM_PASSWORD            1055
#define IDT_PKCS5_PRF                   1056
#define IDT_PW_CACHE_OPTIONS            1057
#define IDT_DEFAULT_MOUNT_OPTIONS       1058
#define IDT_WINDOWS_RELATED_SETTING     1059
#define IDC_CREATE                      1060
#define IDC_EXIT                        1061
#define IDC_TRAVEL_OPEN_EXPLORER        1062
#define IDC_TRAV_CACHE_PASSWORDS        1063
#define IDC_UNMOUNTALL                  1064
#define IDT_TASKBAR_ICON                1065
#define IDT_AUTO_DISMOUNT               1066
#define IDC_PREF_FORCE_AUTO_DISMOUNT    1067
#define IDC_PREF_DISMOUNT_INACTIVE_TIME 1068
#define IDT_MINUTES                     1069
#define IDC_PREF_DISMOUNT_SCREENSAVER   1070
#define IDC_PREF_DISMOUNT_POWERSAVING   1071
#define IDT_AUTO_DISMOUNT_ON            1072
#define IDC_PREF_WIPE_CACHE_ON_AUTODISMOUNT 1073
#define IDC_CLOSE_BKG_TASK_WHEN_NOVOL   1074
#define IDT_LOGON                       1075
#define IDC_PREF_LOGON_START            1076
#define IDC_PREF_LOGON_MOUNT_DEVICES    1077
#define IDC_PREF_LOGON_MOUNT_FAVORITES  1078
#define IDC_SHOW_PASSWORD_CHPWD_NEW     1079
#define IDC_DISMOUNT_CONFIRM_MSG_BOX    1080
#define IDC_SHOW_PASSWORD_CHPWD_ORI     1081
#define IDC_DISMOUNT_CONFIRM_PLAY_SOUND 1082
#define IDC_HOTKEY_ASSIGN               1083
#define IDC_HOTKEY_REMOVE               1084
#define IDC_HOTKEY_KEY                  1085
#define IDT_HOTKEY_KEY                  1086
#define IDC_HOTKEY_LIST                 1087
#define IDC_RESET_HOTKEYS               1088
#define IDT_DISMOUNT_ACTION             1089
#define IDT_ASSIGN_HOTKEY               1090
#define IDC_HK_MOD_SHIFT                1091
#define IDC_HK_MOD_CTRL                 1092
#define IDC_HK_MOD_ALT                  1093
#define IDC_HK_MOD_WIN                  1094
#define IDC_SHOW_PASSWORD               1095
#define IDC_LOGO                        1096
#define IDT_PKCS11_LIB_PATH             1097
#define IDC_PKCS11_MODULE               1098
#define IDC_SELECT_PKCS11_MODULE        1099
#define IDC_AUTO_DETECT_PKCS11_MODULE   1100
#define IDC_CLOSE_TOKEN_SESSION_AFTER_MOUNT 1101
#define IDT_SECURITY_OPTIONS            1102
#define IDC_DISABLE_BOOT_LOADER_OUTPUT  1103
#define IDC_ALLOW_ESC_PBA_BYPASS        1104
#define IDC_CUSTOM_BOOT_LOADER_MESSAGE  1105
#define IDC_BOOT_LOADER_CACHE_PASSWORD  1106
#define IDC_MORE_SETTINGS               1107
#define IDT_CUSTOM_BOOT_LOADER_MESSAGE  1108
#define IDC_CUSTOM_BOOT_LOADER_MESSAGE_HELP 1109
#define IDT_BOOT_LOADER_SCREEN_OPTIONS  1110
#define IDT_PKCS11_LIB_HELP             1111
#define IDT_SYSTEM_FAVORITES_OPTIONS    1112
#define IDC_MOUNT_SYSTEM_FAVORITES_ON_BOOT 1113
#define IDC_DISABLE_NONADMIN_SYS_FAVORITES_ACCESS 1114
#define IDM_HELP                        40001
#define IDM_ABOUT                       40002
#define IDM_UNMOUNT_VOLUME              40003
#define IDM_CLEAR_HISTORY               40004
#define IDM_FORUMS                      40005
#define IDM_BENCHMARK                   40006
#define IDM_TRAVELER                    40007
#define IDM_MOUNT_VOLUME_OPTIONS        40008
#define IDM_FAQ                         40009
#define IDM_REFRESH_DRIVE_LETTERS       40010
#define IDM_DEFAULT_KEYFILES            40011
#define IDM_WEBSITE                     40012
#define IDM_MOUNTALL                    40013
#define IDM_UNMOUNTALL                  40014
#define IDM_MOUNT_VOLUME                40015
#define IDM_CHANGE_PASSWORD             40016
#define IDM_VOLUME_WIZARD               40017
#define IDM_CREATE_VOLUME               40018
#define IDM_WIPE_CACHE                  40019
#define IDM_PREFERENCES                 40020
#define IDM_LICENSE                     40021
#define IDM_SELECT_FILE                 40022
#define IDM_SELECT_DEVICE               40023
#define IDM_VOLUME_PROPERTIES           40024
#define IDM_LANGUAGE                    40025
#define IDM_MOUNT_FAVORITE_VOLUMES      40026
#define IDM_SAVE_FAVORITE_VOLUMES       40027
#define IDM_BACKUP_VOL_HEADER           40028
#define IDM_RESTORE_VOL_HEADER          40029
#define IDM_HOTKEY_SETTINGS             40030
#define IDM_TC_DOWNLOADS                40031
#define IDM_NEWS                        40032
#define IDM_BUGREPORT                   40033
#define IDM_CONTACT                     40034
#define IDM_VERSION_HISTORY             40035
#define IDM_HOMEPAGE                    40036
#define IDM_TEST_VECTORS                40037
#define IDM_ADD_REMOVE_VOL_KEYFILES     40038
#define IDM_REMOVE_ALL_KEYFILES_FROM_VOL 40039
#define IDM_GENERATE_KEYFILE            40040
#define IDM_CHANGE_HEADER_KEY_DERIV_ALGO 40041
#define IDM_KEYFILE_GENERATOR           40042
#define IDM_SET_DEFAULT_KEYFILES        40043
#define IDM_ONLINE_TUTORIAL             40044
#define IDM_ONLINE_HELP                 40045
#define IDM_DONATIONS                   40046
#define IDM_CHANGE_SYS_HEADER_KEY_DERIV_ALGO 40047
#define IDM_CHANGE_SYS_PASSWORD         40048
#define IDM_CREATE_RESCUE_DISK          40049
#define IDM_PERMANENTLY_DECRYPT_SYS     40050
#define IDM_VERIFY_RESCUE_DISK          40051
#define IDM_SYSTEM_ENCRYPTION_STATUS    40052
#define IDM_ENCRYPT_SYSTEM_DEVICE       40053
#define IDM_SYSENC_RESUME               40054
#define IDM_MOUNT_SYSENC_PART_WITHOUT_PBA 40055
#define IDM_CREATE_HIDDEN_OS            40056
#define IDM_TOKEN_PREFERENCES           40057
#define IDM_CLOSE_ALL_TOKEN_SESSIONS    40058
#define IDM_SYS_ENC_SETTINGS            40059
#define IDM_SYSENC_SETTINGS             40060
#define IDM_RESUME_INTERRUPTED_PROC     40061
#define IDM_MANAGE_TOKEN_KEYFILES       40062
#define IDM_SAVE_SYSTEM_FAVORITE_VOLUMES 40063
#define IDM_SYS_FAVORITES_SETTINGS      40064

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        117
#define _APS_NEXT_COMMAND_VALUE         40065
#define _APS_NEXT_CONTROL_VALUE         1115
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
